@@ -6,8 +6,11 @@ import pyross.hybrid
 import pyross.inference
 import pyross.stochastic
 import pyross.utils
-import pyross.utils_python 
+import pyross.utils_python
+import pyross.evidence
+import pyross.tsi.deterministic
+import pyross.tsi.utils
 
 ## current version of PyRoss
-__version__="1.2.8"
+__version__="1.3.8"
 
